@@ -2,7 +2,7 @@
 """
 :Author: HuangJingCan
 :Date: 2020-06-02 13:44:17
-:LastEditTime: 2022-02-17 10:45:08
+:LastEditTime: 2022-02-17 11:30:50
 :LastEditors: HuangJingCan
 :description: 奖品相关（包含箱数相关）接口
 """
@@ -16,12 +16,12 @@ from seven_cloudapp_frame.models.db_models.act.act_prize_model import *
 from seven_cloudapp_frame.models.db_models.prize.prize_roster_model import *
 from seven_cloudapp_frame.models.launch_base_model import LaunchBaseModel
 
-from seven_cloudapp_frame.models.enum import *
-from seven_cloudapp_frame.models.business_base_model import *
-from seven_cloudapp_frame.models.db_models.act.act_module_ex_model import *
-from seven_cloudapp_frame.models.db_models.act.act_prize_ex_model import *
-from seven_cloudapp_frame.models.db_models.prize.prize_roster_ex_model import *
-from seven_cloudapp_frame.models.db_models.act.act_prize_senior_config_model import *
+from seven_cloudapp_ndjyfs.models.enum import *
+from seven_cloudapp_ndjyfs.models.business_base_model import *
+from seven_cloudapp_ndjyfs.models.db_models.act.act_module_ex_model import *
+from seven_cloudapp_ndjyfs.models.db_models.act.act_prize_ex_model import *
+from seven_cloudapp_ndjyfs.models.db_models.prize.prize_roster_ex_model import *
+from seven_cloudapp_ndjyfs.models.db_models.act.act_prize_senior_config_model import *
 
 
 class PrizeHandler(ClientBaseHandler):
